@@ -56,7 +56,7 @@ clutter_stage_egl_unrealize (ClutterStageWindow *stage_window)
 
   if (stage_egl->egl_surface != EGL_NO_SURFACE)
     {
-      eglDestroySurface (clutter_eglx_display (), stage_egl->egl_surface);
+      eglDestroySurface (clutter_egl_get_egl_display (), stage_egl->egl_surface);
       stage_egl->egl_surface = EGL_NO_SURFACE;
     }
 
@@ -81,7 +81,7 @@ clutter_stage_egl_realize (ClutterStageWindow *stage_window)
   backend_egl = CLUTTER_BACKEND_EGL (backend);
   backend_x11 = CLUTTER_BACKEND_X11 (backend);
 
-  edpy = clutter_eglx_display ();
+  edpy = clutter_egl_get_egl_display ();
 
   if (stage_x11->xwin == None)
     {
@@ -455,11 +455,14 @@ _clutter_stage_egl_redraw (ClutterStageEGL *stage_egl,
       stage_egl->bounding_redraw_clip.width != 0 &&
       /* some drivers struggle to get going and produce some junk
        * frames when starting up... */
-      G_LIKELY (stage_egl->frame_count > 3) &&
+      G_LIKELY (stage_egl->frame_count > 3)
+#ifdef COGL_HAS_X11_SUPPORT
       /* While resizing a window clipped redraws are disabled to avoid
        * artefacts. See clutter-event-x11.c:event_translate for a
        * detailed explanation */
-      G_LIKELY (stage_x11->clipped_redraws_cool_off == 0))
+      && G_LIKELY (stage_x11->clipped_redraws_cool_off == 0)
+#endif
+      )
     may_use_clipped_redraw = TRUE;
   else
     may_use_clipped_redraw = FALSE;
