@@ -33,11 +33,15 @@
 #include "clutter-keymap-x11.h"
 #include "clutter-x11.h"
 
-#include "../clutter-backend.h"
-#include "../clutter-event.h"
-#include "../clutter-private.h"
-#include "../clutter-debug.h"
-#include "../clutter-main.h"
+#include "clutter-actor-private.h"
+#include "clutter-backend-private.h"
+#include "clutter-debug.h"
+#include "clutter-device-manager-private.h"
+#include "clutter-event.h"
+#include "clutter-main.h"
+#include "clutter-paint-volume-private.h"
+#include "clutter-private.h"
+#include "clutter-stage-private.h"
 
 #include "cogl/cogl-internal.h"
 
@@ -144,10 +148,7 @@ clutter_event_source_new (ClutterBackend *backend)
   GSource *source = g_source_new (&event_funcs, sizeof (ClutterEventSource));
   ClutterEventSource *event_source = (ClutterEventSource *) source;
 
-#if GLIB_CHECK_VERSION (2, 25, 8)
   g_source_set_name (source, "Clutter X11 Event");
-#endif
-
   event_source->backend = backend;
 
   return source;
@@ -737,12 +738,11 @@ event_translate (ClutterBackend *backend,
 
     case Expose:
       {
-        CLUTTER_NOTE (MULTISTAGE, "expose for stage: %p, redrawing", stage);
-        clutter_actor_queue_redraw (CLUTTER_ACTOR (stage));
         XExposeEvent *expose = (XExposeEvent *)xevent;
         ClutterPaintVolume clip;
         ClutterVertex origin;
 
+        CLUTTER_NOTE (MULTISTAGE, "expose for stage: %p, redrawing", stage);
         CLUTTER_NOTE (MULTISTAGE,
                       "expose for stage: %p, "
                       "redrawing (x=%d, y=%d, width=%d, height=%d)",
